==> akonadi-16.12.1.tar.xz: akonadi-16.12.1/src/server/handler/create.h <==
/***************************************************************************
 *   Copyright (C) 2006 by Ingo Kloecker <kloecker@kde.org>                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef AKONADICREATE_H
#define AKONADICREATE_H

#include "handler.h"

namespace Akonadi {
namespace Server {

/**
  @ingroup akonadi_server_handler

  Handler for the CREATE command. CREATE is backward-compatible with RFC 3051,
  except recursive collection creation.

  Response:
  A untagged response identical to AkList is sent for every created collection.
 */
class Create : public Handler
{
    Q_OBJECT
public:
    bool parseStream() Q_DECL_OVERRIDE;
};

} // namespace Server
} // namespace Akonadi

#endif

==> akonadi-17.07.80.tar.xz: akonadi-17.07.80/src/server/handler/create.h <==
/***************************************************************************
 *   Copyright (C) 2006 by Ingo Kloecker <kloecker@kde.org>                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef AKONADICREATE_H
#define AKONADICREATE_H

#include "handler.h"

namespace Akonadi
{
namespace Server
{

/**
  @ingroup akonadi_server_handler

  Handler for the CREATE command. CREATE is backward-compatible with RFC 3051,
  except recursive collection creation.

  Response:
  A untagged response identical to AkList is sent for every created collection.
 */
class Create : public Handler
{
    Q_OBJECT
public:
    bool parseStream() override;
};

} // namespace Server
} // namespace Akonadi

#endif
